summaryrefslogtreecommitdiffstats
path: root/lib/public
diff options
context:
space:
mode:
authorRobin Appelman <icewind@owncloud.com>2014-01-27 15:56:57 +0100
committerRobin Appelman <icewind@owncloud.com>2014-01-27 15:56:57 +0100
commit3c1ab66edac1ba2f1b398c859cd933c410ea3d8d (patch)
treebdd26dd256e1668751dde67d848ac4ab2a191c11 /lib/public
parentd182b4f59fd7b172764a4d802dbd3ee6a953ea39 (diff)
downloadnextcloud-server-3c1ab66edac1ba2f1b398c859cd933c410ea3d8d.tar.gz
nextcloud-server-3c1ab66edac1ba2f1b398c859cd933c410ea3d8d.zip
Reuse the calculated free_space in buildFileStorageStatistics
Diffstat (limited to 'lib/public')
-rw-r--r--lib/public/util.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/public/util.php b/lib/public/util.php
index 6317f10a66f..52874bcc954 100644
--- a/lib/public/util.php
+++ b/lib/public/util.php
@@ -456,10 +456,11 @@ class Util {
/**
* calculates the maximum upload size respecting system settings, free space and user quota
*
* @param $dir the current folder where the user currently operates
* @return number of bytes representing
*/
- public static function maxUploadFilesize($dir) {
- return \OC_Helper::maxUploadFilesize($dir);
+ public static function maxUploadFilesize($dir, $free = null) {
+ return \OC_Helper::maxUploadFilesize($dir, $free);
}
}
@@ -456,10 +456,11 @@ class Util {
* calculates the maximum upload size respecting system settings, free space and user quota
*
- * @param $dir the current folder where the user currently operates
+ * @param string $dir the current folder where the user currently operates
+ * @param int $free the number of bytes free on the storage holding $dir, if not set this will be received from the storage directly
* @return number of bytes representing
*/